@@ -43,14 +43,18 @@
 #' @template MRS
 #' @export
 TernaryPointValues <- function(Func, resolution = 48L, 
-                               direction = getOption('ternDirection'), ...) {
+                               direction = getOption('ternDirection', 1L), ...) {
   triangleCentres <- TriangleCentres(resolution, direction)
   x <- triangleCentres['x', ]
   y <- triangleCentres['y', ]
   abc <- XYToTernary(x, y, direction)
+  z <- Func(abc[1, ], abc[2, ], abc[3, ], ...)
+  if (length(z) < length(x)) {
+    warning("`Func(a, b, c)` should return a vector, but returned a single value.")
+  }
   
   # Return:
-  rbind(x = x, y = y, z = Func(abc[1, ], abc[2, ], abc[3, ], ...), 
+  rbind(x = x, y = y, z = z, 
         down = triangleCentres['triDown', ])
 }
 
@@ -76,7 +80,7 @@ TernaryPointValues <- function(Func, resolution = 48L,
 #' @template MRS
 #' @export
 TriangleCentres <- function (resolution = 48L, 
-                             direction = getOption('ternDirection')) {
+                             direction = getOption('ternDirection', 1L)) {
   
   offset <- 1 / resolution / 2L
   triangleHeight <- sqrt(0.75) / resolution
@@ -151,7 +155,7 @@ TriangleCentres <- function (resolution = 48L,
 #' @template coordinatesParam
 #' @export
 TernaryDensity <- function (coordinates, resolution = 48L, 
-                            direction = getOption('ternDirection')) {
+                            direction = getOption('ternDirection', 1L)) {
   if (inherits(coordinates, 'list')) {
     scaled <- resolution * 
       vapply(coordinates,function (coord) coord / sum(coord), double(3L))
@@ -384,7 +388,7 @@ TernaryRightTiles <- function(x, y, resolution, col) {
 #' @family functions for colouring and shading
 #' @export
 TernaryTiles <- function (x, y, down, resolution, col, 
-                          direction = getOption('ternDirection')) {
+                          direction = getOption('ternDirection', 1L)) {
   down <- as.logical(down)
   if (direction %% 2) {
     TernaryDownTiles(x[down], y[down], resolution, col[down])
@@ -447,7 +451,7 @@ TernaryTiles <- function (x, y, down, resolution, col,
 ColourTernary <- function (values, 
                            spectrum = viridisLite::viridis(256L, alpha = 0.6),
                            resolution = sqrt(ncol(values)),
-                           direction = getOption('ternDirection')) {
+                           direction = getOption('ternDirection', 1L)) {
   z <- values['z', ]
   col <- if (is.null(spectrum) || (!is.numeric(z) && all(
       suppressWarnings(is.na(as.numeric(z)))) && 
@@ -495,11 +499,33 @@ ColorTernary <- ColourTernary
 #' ColourTernary(values)
 #' TernaryContour(FunctionToContour, resolution = 36L)
 #' 
+#' # Note that FunctionToContour is sent a vector.
+#' # Instead of
+#' BadMax <- function (a, b, c) {
+#'   max(a, b, c) 
+#' }
+#' 
+#' # Use
+#' GoodMax <- function (a, b, c) {
+#'   pmax(a, b, c)
+#' }
+#' TernaryPlot(alab = 'a', blab = 'b', clab = 'c')
+#' ColourTernary(TernaryPointValues(GoodMax))
+#' TernaryContour(GoodMax)
+#' 
+#' # Or, for a generalizable example,
+#' GeneralMax <- function (a, b, c) {
+#'   apply(rbind(a, b, c), 2, max)
+#' }
+#' TernaryPlot(alab = 'a', blab = 'b', clab = 'c')
+#' ColourTernary(TernaryPointValues(GeneralMax))
+#' TernaryContour(GeneralMax)
+#' 
 #' @family contour plotting functions
 #' @importFrom graphics contour
 #' @export
 TernaryContour <- function (Func, resolution = 96L, 
-                            direction = getOption('ternDirection'), ...) {
+                            direction = getOption('ternDirection', 1L), ...) {
   if (direction == 1L) {
     x <- seq(-0.5, 0.5, length.out = resolution)
     y <- seq(0, sqrt(0.75), length.out = resolution)
@@ -516,10 +542,18 @@ TernaryContour <- function (Func, resolution = 96L,
   
   FunctionWrapper <- function(x, y) {
     abc <- XYToTernary(x, y, direction)
-    # TODO make more efficient by doing this intelligently rather than lazily
-    ifelse(apply(abc < -0.6 / resolution, 2, any),
-           NA,
-           Func(abc[1, ], abc[2, ], abc[3, ]))
+    
+    inPlot <- apply(abc > -0.6 / resolution, 2, all)
+    ret <- rep_len(NA_real_, length(x))
+    evaluated <- Func(abc[1, inPlot], abc[2, inPlot], abc[3, inPlot])
+    
+    if (length(evaluated) == 1L) {
+      warning("`Func(a, b, c)` should return a vector, but returned a single value.")
+    }
+    
+    ret[inPlot] <- evaluated
+    # Return:
+    ret
   }
   z <- outer(X = x, Y = y, FUN = FunctionWrapper)
   contour(x, y, z, add = TRUE, ...)
@@ -588,7 +622,7 @@ TernaryContour <- function (Func, resolution = 96L,
 TernaryDensityContour <- function (coordinates, bandwidth, resolution = 25L, 
                                    tolerance = -0.2 / resolution,
                                    edgeCorrection = TRUE,
-                                   direction = getOption('ternDirection'),
+                                   direction = getOption('ternDirection', 1L),
                                    ...) {
   # Adapted from MASS::kde2d
   xy <- apply(coordinates, 1, TernaryCoords)
